==> duiba-galaxy-sdk-0.0.1-20221012.113454-1-sources.jar: cn/com/duiba/galaxy/sdk/datas/UserSpRecordNew.java <==
package cn.com.duiba.galaxy.sdk.datas;

import java.io.Serializable;
import java.util.Date;

/**
 * Description:
 * <p>
 * date: 2021/11/11 3:26 下午
 *
 * @author huakai
 */
public class UserSpRecordNew implements Serializable {
    private Long id;

    private String projectId; //项目ID

    private String playwayId; //玩法ID

    private String actionId; //接口ID

    private String userId; //用户ID

    private String spId; //奖项ID

    private String changedType;//道具变更类型 - 或 +

    private Long quantity; //变更数量

    private Date gmtCreate; //创建时间

    private Date gmtModified; //变更时间

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getPlaywayId() {
        return playwayId;
    }

    public void setPlaywayId(String playwayId) {
        this.playwayId = playwayId;
    }

    public String getActionId() {
        return actionId;
    }

    public void setActionId(String actionId) {
        this.actionId = actionId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getSpId() {
        return spId;
    }

    public void setSpId(String spId) {
        this.spId = spId;
    }

    public String getChangedType() {
        return changedType;
    }

    public void setChangedType(String changedType) {
        this.changedType = changedType;
    }

    public Long getQuantity() {
        return quantity;
    }

    public void setQuantity(Long quantity) {
        this.quantity = quantity;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    @Override
    public String toString() {
        return "UserSpRecordNew{" +
                "id=" + id +
                ", projectId='" + projectId + '\'' +
                ", playwayId='" + playwayId + '\'' +
                ", actionId='" + actionId + '\'' +
                ", userId='" + userId + '\'' +
                ", spId='" + spId + '\'' +
                ", changedType='" + changedType + '\'' +
                ", quantity=" + quantity +
                ", gmtCreate=" + gmtCreate +
                ", gmtModified=" + gmtModified +
                '}';
    }
}

==> duiba-galaxy-sdk-0.0.3-sources.jar: cn/com/duiba/galaxy/sdk/datas/UserSpRecordNew.java <==
package cn.com.duiba.galaxy.sdk.datas;

import java.io.Serializable;
import java.util.Date;

/**
 * Description:
 * <p>
 * date: 2021/11/11 3:26 下午
 *
 * @author huakai
 */
public class UserSpRecordNew implements Serializable {
    private Long id;

    private Long projectId; //项目ID

    private String playwayId; //玩法ID

    private String actionId; //接口ID

    private Long userId; //用户ID

    private String spId; //奖项ID

    private String changedType;//道具变更类型 - 或 +

    private Long quantity; //变更数量

    private Date gmtCreate; //创建时间

    private Date gmtModified; //变更时间

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getPlaywayId() {
        return playwayId;
    }

    public void setPlaywayId(String playwayId) {
        this.playwayId = playwayId;
    }

    public String getActionId() {
        return actionId;
    }

    public void setActionId(String actionId) {
        this.actionId = actionId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getSpId() {
        return spId;
    }

    public void setSpId(String spId) {
        this.spId = spId;
    }

    public String getChangedType() {
        return changedType;
    }

    public void setChangedType(String changedType) {
        this.changedType = changedType;
    }

    public Long getQuantity() {
        return quantity;
    }

    public void setQuantity(Long quantity) {
        this.quantity = quantity;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    @Override
    public String toString() {
        return "UserSpRecordNew{" +
                "id=" + id +
                ", projectId='" + projectId + '\'' +
                ", playwayId='" + playwayId + '\'' +
                ", actionId='" + actionId + '\'' +
                ", userId='" + userId + '\'' +
                ", spId='" + spId + '\'' +
                ", changedType='" + changedType + '\'' +
                ", quantity=" + quantity +
                ", gmtCreate=" + gmtCreate +
                ", gmtModified=" + gmtModified +
                '}';
    }
}
